﻿local mod = LootMaster:NewModule("EPGPLootmaster_Options")

function mod:OnEnable()
  local options = {
    name = "EPGP LootMaster",
    type = "group",
    get = function(i) return LootMaster.db.profile[i[#i]] end,
    set = function(i, v) LootMaster.db.profile[i[#i]] = v end,
    args = {
        help = {
            order = 0,
            type = "description",
            name = "EPGP is an in game, relational loot distribution system. LootMaster helps you distribute loot to your raid and registers this loot in the EPGP system.",
        },
        hint = {
            order = 1,
            type = "description",
            name = "Hint: You can open these options by typing /lm config",
        },
        auto_announce_threshold = {
            order = 13,
            type = "select",
            name = "Auto loot announce threshold",
            desc = "Sets automatic loot announcement threshold, any loot that qualifies will get auto announced to the raid members.",
            values = {
                [0] = 'Off',
                [2] = ITEM_QUALITY2_DESC,
                [3] = ITEM_QUALITY3_DESC,
                [4] = ITEM_QUALITY4_DESC,
                [5] = ITEM_QUALITY5_DESC,
            },
        },
        loot_timeout = {
            order = 14,
            type = "select",
            name = "Loot selection timeout",
            desc = "Sets the amount of time a loot candidate has to select wether they want the loot or not.",
            values = {
                [0] = 'No timeout',
                [10] = '10 secs',
                [15] = '15 secs',
                [20] = '20 secs',
                [30] = '30 secs',
                [40] = '40 secs',
                [50] = '50 secs',
                [60] = '1 minute',
                [90] = '1 min 30 sec',
                [150] = '2 min 30 sec',
                [300] = '5 min',
            },
        },
      
        
        UseAutoLoot = {
            type = "toggle",
            order = 15,
            width = 'full',
            name = "Auto send BoE and BoU items below the threshold to:",
            desc = "Check if you want to send BoE and BoU items below threshold to a specified player automatically",
            disabled = false,
        },
        AutoLootGroup = {
					type = "group",
					order = 16,
					guiInline = true,
					name = "",
					desc = "Use Auto Show/Hide",
					disabled = function(info) return not LootMaster.db.profile.UseAutoLoot end,
					args = {
                        AutoLooter = {
							type = "select",
                            style = 'dropdown',
							order = 1,
                            width = 'full',
							name = "Name of the default candidate (case sensitive):",
							desc = "Please enter the name of the default candidate to receive the BoE and BoU items here.",
                            values = function()
                                local names = {}
                                local name;
                                local num = GetNumRaidMembers()
                                if num>0 then
                                    -- we're in raid
                                    for i=1, num do 
                                        name = GetRaidRosterInfo(i)
                                        names[name] = name
                                    end
                                else
                                    num = GetNumPartyMembers()
                                    if num>0 then
                                        -- we're in party
                                        for i=1, num do 
                                            names[UnitName('party'..i)] = UnitName('party'..i)
                                        end
                                        names[UnitName('player')] = UnitName('player')
                                    else
                                        -- Just show everyone in guild.
                                        local num = GetNumGuildMembers(true);
                                        for i=1, num do repeat
                                            name = GetGuildRosterInfo(i)
                                            names[name] = name
                                        until true end     
                                    end                                   
                                end
                                sort(names)
                                return names;
                            end
						},
                    }
        },
        
        monitor = {
            type = "toggle",
            set = function(i, v)
                LootMaster.db.profile[i[#i]] = v;
                if LootMasterML and LootMasterML.UpdateUI then
                    LootMasterML.UpdateUI( LootMasterML );
                end
            end,
            order = 17,
            width = 'full',
            name = "Listen for incoming monitor updates",
            desc = "Check if you want display monitor updates. This functions allows other raidmembers to see the masterlooter interface so they can help in making decisions about the loot distribution.",
            disabled = false,
        },
    },
  }

  local config = LibStub("AceConfig-3.0")
  local dialog = LibStub("AceConfigDialog-3.0")

  config:RegisterOptionsTable("EPGPLootMaster-Bliz", options)
  dialog:AddToBlizOptions("EPGPLootMaster-Bliz", "EPGPLootMaster")
  
end